Management commands — django-sphinxdoc 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »

# Management commands

One management command is provided with this app.

## `updatedoc`

Management command for updading the documentation of one or more projects.

class `sphinxdoc.management.commands.updatedoc.` `Command`

  Update (and optionally build) the Sphinx documentation for one ore more projects.

  You need to pass the slug of at least one project. If you pass the optional parameter `-b`, the command `sphinx-build` will be run for each project before their files are read. If your project(s) are located in a different virtualenv than your django site, you can provide a path to its interpreter with `--virtualenv path/to/env/bin/`

  `build`(project, virtualenv='')

    Runs `sphinx-build` for `project`. You can also specify a path to the bin-directory of a `virtualenv`, if your project requires it.

  `delete_documents`(project)

    Deletes all documents for `project`.

  `handle`(*args, **options)

    Updates (and optionally builds) the documenation for all projects, either as a list specifed in `args`, or get all from database.

  `import_files`(project)

    Creates a `Document` instance for each JSON file of `project`.

  `update_haystack`()

    Updates Haystack’s search index.

### Navigation

- index
- modules |
- next |
- previous |
- django-sphinxdoc 1.2.0 documentation »
- API-Reference »